@@ -59,12 +59,6 @@ class WPSRequest:
         self.timeout    = cfg.getint('response_timeout')
         self.expiration = cfg.getint('response_expiration')
     
-    @property
-    def status_url(self) -> Optional[str]:
-        if self.status_link:
-            return f"{self.host_url.rstrip('/')}{self.status_link}"
-        else:
-            return None
 
     @staticmethod
     def must_check_realm(realm: str) -> bool:
@@ -111,14 +105,6 @@ class WPSRequest:
     def dumps( self ):
         return json.dumps(self.json, allow_nan=False)
 
-    #
-    # Execute
-    #
-    async def execute(self, service: Service, uuid: UUID, 
-                      map_uri: Optional[str]=None) -> bytes:
-        
-        return await service.execute(self.identifier, self, uuid, map_uri)
-
 
 class WPSResponse:
 
