@@ -16,7 +16,10 @@ import logging
 from pyqgiswps.app.request import WPSRequest
 from pyqgiswps.app.process import WPSProcess
 from pyqgiswps.config import confservice
-from pyqgiswps.exceptions import (MissingParameterValue, NoApplicableCode)
+from pyqgiswps.exceptions import (
+    MissingParameterValue, 
+    NoApplicableCode, 
+)
 from pyqgiswps.inout.inputs import ComplexInput, LiteralInput, BoundingBoxInput
 from pyqgiswps.executors.processingexecutor import ProcessingExecutor
 
@@ -62,7 +65,7 @@ class Service():
     def get_results(self, uuid: str) -> Any:
         doc = self.executor.get_results(uuid)
         if doc is None:
-            raise NoApplicableCode('No results found for %s' % uuid, code=404)
+            raise NoApplicableCode(f"No results found for {uuid}", code=404)
 
         return doc
 
@@ -81,16 +84,6 @@ class Service():
         """
         return self.executor.kill_job(uuid, pid)
 
-    async def execute(self, identifier: str, wps_request: WPSRequest, uuid: str, 
-                      map_uri: Optional[str]=None) -> bytes:
-        """Parse and perform Execute WPS request call
-        
-        :param identifier: process identifier string
-        :param wps_request: pyqgiswps.WPSRequest structure with parsed inputs, still in memory
-        :param uuid: string identifier of the request
-        """
-        process = self.get_process(identifier, map_uri=map_uri)
-        return await self.execute_process(process, wps_request, uuid)
 
     async def execute_process(self, process: WPSProcess, wps_request: WPSRequest, uuid: str) -> bytes:
         """Parse and perform Execute WPS request call
