@@ -40,7 +40,10 @@ def _log( *args ):
 def getenv2( env1, env2, default):
     """ Get value from alternate env variable
     """
-    return getenv(env1,getenv(env2,default))
+    value = getenv(env1)
+    if value is None:
+        value = getenv(env2,default)
+    return value
 
 
 def load_configuration():
@@ -62,11 +65,8 @@ def load_configuration():
     CONFIG.add_section('server')
     CONFIG.set('server', 'encoding', 'utf-8')
     CONFIG.set('server', 'language', 'en-US')
-    CONFIG.set('server', 'url', '{host_url}')
-
     CONFIG.set('server', 'port'          , getenv('QGSWPS_SERVER_HTTP_PORT', '8080'))
     CONFIG.set('server', 'interfaces'    , getenv('QGSWPS_SERVER_INTERFACES', '0.0.0.0'))
-
     # Select if output files are returned by reference or in response body
     CONFIG.set('server', 'outputfile_as_reference', getenv('QGSWPS_SERVER_OUTPUTFILE_AS_REFERENCE', 'yes'))
     # Max input file fetched as remote reference
@@ -76,7 +76,11 @@ def load_configuration():
     # Path to workdir where process are executed"
     CONFIG.set('server', 'workdir'              , getenv('QGSWPS_SERVER_WORKDIR',tempfile.gettempdir()))
     # Configure host if the server is behind a proxy
-    CONFIG.set('server', 'host_proxy'           , getenv('QGSWPS_SERVER_HOST_PROXY',''))
+    # XXX DEPRECATED -> Use 'proxy_url'
+    CONFIG.set('server', 'host_proxy', getenv('QGSWPS_SERVER_HOST_PROXY',''))
+    CONFIG.set('server', 'proxy_url' , getenv('QGSWPS_SERVER_PROXY_URL', '${host_proxy}'))
+    # Allow proxyfication
+    CONFIG.set('server', 'http_proxy'           , getenv('QGSWPS_SERVER_HTTP_PROXY','yes'))
     # Number of parallel processes that are allowed to run algorithms
     CONFIG.set('server', 'parallelprocesses'    , getenv('QGSWPS_SERVER_PARALLELPROCESSES','1'))
     # Maximal number of executions can run in the same worker before beeing restarted
@@ -249,8 +253,8 @@ def load_configuration():
     CONFIG.set('metadata:oapi', 'contact_address', '${metadata:contact_address}')
     CONFIG.set('metadata:oapi', 'contact_email', '${metadata:contact_email}')
     CONFIG.set('metadata:oapi', 'contact_url', '${metadata:contact_url}')
-    CONFIG.set('metadata:oapi', 'licence_name','${metadata:licence_url}')
-    CONFIG.set('metadata:oapi', 'licence_url','${metadata:licence_name}')
+    CONFIG.set('metadata:oapi', 'licence_name','${metadata:licence_name}')
+    CONFIG.set('metadata:oapi', 'licence_url','${metadata:licence_url}')
     CONFIG.set('metadata:oapi', 'contact_role','${metadata:contact_role}')
     CONFIG.set('metadata:oapi', 'external_doc_description','Py-qgis-wps server documentation')
     CONFIG.set('metadata:oapi', 'external_doc_url','https://docs.3liz.org/py-qgis-wps/')
