@@ -28,9 +28,10 @@ LOGGER = logging.getLogger('SRVLOG')
 class OWSHandler(BaseHandler):
     """ Handle WPS requests
     """
-    def initialize(self, access_policy):
+    def initialize(self, access_policy, service_url):
         super().initialize()
-   
+
+        self.service_url = service_url
         self.accesspolicy = access_policy
 
     def get_job_realm(self):
@@ -42,6 +43,12 @@ class OWSHandler(BaseHandler):
             realm = uuid.uuid4().hex
         return realm
 
+    def check_service(self) -> None:
+        # Require SERVICE argument
+        service = self.get_argument('SERVICE')
+        if service.upper() != 'WPS':
+            raise InvalidParameterValue('parameter SERVICE [%s] not supported' % service, 'service')
+
     async def handle_wps_request(self, method_parser):
         """ Handle a wps request
         """
@@ -50,6 +57,12 @@ class OWSHandler(BaseHandler):
         wpsrequest.map_uri  = self.get_argument('MAP', default=None)
         wpsrequest.host_url = self.proxy_url()
 
+        # Check for service url
+        wpsrequest.service_url = self.service_url \
+            or self.request.headers.get('X-Qgis-Wps-Service-Url', default=None) \
+            or self.request.headers.get('X-Qgis-Service-Url', default=None) \
+            or f"{wpsrequest.host_url}ows/"
+
         service = self.application.wpsservice
         LOGGER.debug('Request: %s', wpsrequest.operation)
 
@@ -72,7 +85,9 @@ class OWSHandler(BaseHandler):
 
             # Assign job realm
             wpsrequest.realm = self.get_job_realm()
-            # Status link
+            wpsrequest.status_uuid = job_id
+
+            # Canonical status link
             wpsrequest.status_link = f"/ows/?service=WPS&request=GetResults&uuid={job_id}"
 
             response = await wpsrequest.execute(service, job_id, map_uri=wpsrequest.map_uri)
@@ -87,10 +102,7 @@ class OWSHandler(BaseHandler):
     async def get(self):
         """ Handle Get Method
         """
-        service = self.get_argument('SERVICE')
-        if service.lower() != 'wps':
-            raise InvalidParameterValue('parameter SERVICE [%s] not supported' % service, 'service')
-
+        self.check_service()
         document = await self.handle_wps_request(OWSRequest.parse_get_request)
 
         self.write_xml(document)
@@ -101,6 +113,7 @@ class OWSHandler(BaseHandler):
             XXX Do not forget to set the max_buffer_size in HTTPServer arguments
             see http://www.tornadoweb.org/en/stable/tcpserver.html?highlight=max_buffer_size
         """
+        self.check_service()
         document = await self.handle_wps_request(OWSRequest.parse_post_request)
         
         self.write_xml(document)
