@@ -30,11 +30,15 @@ from pyqgiswps.exceptions import (NoApplicableCode,
 from .schema import OWS, WPS, BoundingBox, xpath_ns, XMLDocument
 from .response import OWSResponse
 
+from ..ogc import OGC_CONFORMANCE_NS
+
 from typing import TypeVar, Optional, Iterable
 
 AccessPolicy = TypeVar('AccessPolicy')
 Service      = TypeVar('Service')
 WPSProcess   = TypeVar('WPSProcess')
+UUID         = TypeVar('UUID')
+
 
 LOGGER = logging.getLogger('SRVLOG')
 
@@ -53,6 +57,16 @@ class OWSRequest(WPSRequest):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.lineage = False
+        # Replacement url used either with 
+        # X-Qgis-Service-Url
+        # X-Qgis-Wps-Service-Url
+        self.service_url = None
+
+    @staticmethod
+    def conformance() -> str:
+        return OGC_CONFORMANCE_NS.OWS_WPS.value
+
+
 
     @staticmethod
     def parse_get_request(handler) -> WPSRequest:
@@ -412,7 +426,7 @@ class OWSRequest(WPSRequest):
 
         doc.append(service_prov_doc)
 
-        server_href = {'{http://www.w3.org/1999/xlink}href': confservice.get('server','url').format(host_url=self.host_url)}
+        server_href = {'{http://www.w3.org/1999/xlink}href': self.service_url}
 
         # Operations Metadata
         operations_metadata_doc = OWS.OperationsMetadata(
@@ -468,11 +482,20 @@ class OWSRequest(WPSRequest):
         try:
             return service.get_processes(idents, map_uri)
         except UnknownProcessError as exc:
-            raise InvalidParameterValue("Unknown process %s" % exc, "identifier") from None
+            raise InvalidParameterValue(f"Unknown process '{exc}'", "identifier") from None
         except Exception as e:
             LOGGER.critical("Exception:\n%s",traceback.format_exc())
             raise NoApplicableCode(str(e), code=500) from None
 
+    async def execute(self, service: Service, uuid: UUID, 
+                      map_uri: Optional[str]=None) -> bytes:
+        try:        
+            process = service.get_process(self.identifier, map_uri=map_uri)
+        except UnknownProcessError as exc:
+            raise InvalidParameterValue(f"Invalid process '{exc}'", "identifier") from None
+
+        return await service.execute_process(process, self, uuid)
+
     #
     # Describe
     #
@@ -524,15 +547,9 @@ def _get_dataelement_value(value_el):
 
 def _get_rawvalue_value(data, encoding=None):
     """Return real value of CDATA section"""
-
-    try:
-        if encoding is None or encoding == "":
-            return data
-        elif encoding == 'base64':
-            return base64.b64decode(data)
+    if encoding == 'base64':
         return base64.b64decode(data)
-    except Exception:
-        return data
+    return data
 
 
 def _get_reference_body(body_element):
